const Base = require('../class/Base');
const Registry = require('@tars/registry');
const Configure = require('@tars/utils').Config;

class Sys extends Base {
  constructor() {
    super();
    this.registry = Registry.New();
    this.configure = new Configure();
  }

  async getAllAddrsByServant(servant) {
    if (!process.env.TAF_CONFIG) {
      const rsp = await require('tx-report-servant').getAllAddrsByServant(servant);
      return rsp.addrs;
    }

    this.configure.parseFile(process.env.TARS_CONFIG);
    const locator = this.configure.get('tars.application.client.locator', undefined);
    if (!this.locator) {
      this.locator = locator;
      this.registry.setLocator(locator);
    } else {
      if (this.locator != locator) {
        this.locator = locator;
        this.registry.resetLocator(locator);
      }
    }
    const eps = await this.registry.findObjectById4All(servant);
    const actives = [];
    const res = [];
    const endpoints = eps.response.arguments.activeEp;
    for (let i = 0, len = endpoints.value.length; i < len; i++) {
      actives.push(`${endpoints.value[i].host}:${endpoints.value[i].port}`);
    }
    this.logger.info(`getAllAddrsByServant: locator=${locator}, servant=${servant}, actives=${actives}`);
    res.push(actives);
    return res;
  }
}

module.exports = Sys;
